@@ -2,6 +2,9 @@ use std::convert::TryFrom;
 use std::fs::File;
 use std::io::{Read, Write};
 use std::path::Path;
+
+#[cfg(feature = "serde")]
+use serde::{Deserialize, Serialize};
 pub use yara_sys::scan_flags::*;
 
 use crate::{errors::*, initialize::InitializationToken, internals, YrString};
@@ -186,7 +189,9 @@ impl Drop for Rules {
 }
 
 /// A rule that matched during a scan.
+
 #[derive(Debug)]
+#[cfg_attr(feature = "serde", derive(Serialize, Deserialize))]
 pub struct Rule<'r> {
     /// Name of the rule.
     pub identifier: &'r str,
@@ -202,6 +207,7 @@ pub struct Rule<'r> {
 
 /// Metadata specified in a rule.
 #[derive(Debug, Eq, PartialEq)]
+#[cfg_attr(feature = "serde", derive(Serialize, Deserialize))]
 pub struct Metadata<'r> {
     pub identifier: &'r str,
     pub value: MetadataValue<'r>,
@@ -209,6 +215,7 @@ pub struct Metadata<'r> {
 
 /// Type of the value in [MetaData](struct.Metadata.html)
 #[derive(Debug, Eq, PartialEq)]
+#[cfg_attr(feature = "serde", derive(Serialize, Deserialize))]
 pub enum MetadataValue<'r> {
     Integer(i64),
     String(&'r str),
